@@ -12,7 +12,7 @@ use namespace::autoclean;
 #------------------------------------------------------------------------------
 # 继承 Netstack::Connector::Role 方法属性,同时具体实现其指定方法
 #------------------------------------------------------------------------------
-with 'Netstack::Config::Role';
+with 'Netstack::Connector::Role';
 
 #------------------------------------------------------------------------------
 # 具体实现 _buildPrompt,设置设备脚本执行成功回显
